@@ -4,13 +4,7 @@ import json
 import inspect
 
 
-params_file = utils.read_arg("params_file", True)
-params = None
-try:
-    with open(params_file, "r", encoding="utf-8") as f:
-        params = json.load(f)
-except Exception as e:
-    print(e)
+params = utils.params
 
 
 def get_ui():
@@ -28,7 +22,7 @@ def get_ui():
             break
 
     if match_ui_file is None:
-        raise Exception("uiData not found for file")
+        return {}
 
     by = params["uiData"]["by"]
 
